.BG
.FN ash1
.TL
Averaged Shifted Histogram Nonparametric Density Function (1-D)
.DN
Computes a 1-D ASH with polynomial kernel weights.
.CS
ash1(bins, m=5, kopt=c(2,2), warn=T)
.RA
.AG bins
list from function `bin1' containing:
.br
`$nc'=integer vector of bin counts and
.br
`$ab'=bin interval.
.OA
.AG m
integer smoothing parameter;  default=5.  The usual
smoothing parameter h = m times the bin width.
.AG kopt
vector of length 2 specifying the kernel, which
is proportional to ( 1 - abs(i/m)**kopt[1] )**kopt[2]:
.br
c(0,0) = uniform kernel
.br
c(1,0) = triangle kernel
.br
c(2,1) = Epanechnikov kernel
.br
c(2,2) = biweight (the default)
.br
c(2,3) = triweight kernel
.AG warn
suppress warning messages if False.
.RT
a list suitable for input to "plot" containing:
.RC x
vector of bin center locations
.RC y
vector of ash estimates
.RC ier
0=normal exit; 1=estimate nonzero outside interval ab
.RC m,ab,kopt
includes these input values for record keeping
.SH REFERENCES
Scott, D.W. (1985).  Averaged Shifted Histograms:
Effective Nonparametric Density Estimators in Several Dimensions.
.ul
Annals of Statistics, 
\fB80\fR, 348-354.
.PP
Scott, D.W. (1992).
.ul
Multivariate Density Estimation: Theory, Practice, and Visualization.
John Wiley & Sons, New York.
.SA
`bin1', `bin2', `ash2', `compress', `density', `ksmooth'
.EX
x <- rnorm(100)              # data
f <- ash1(bin1(x,nbin=50),5) # compute ash estimate
plot( f , type="l" )         # line plot of estimate
.KW ash, kernel, density, histogram, binning
.WR
